.. MetaTiME documentation master file, created by
   sphinx-quickstart on Fri Apr 29 17:39:34 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MetaTiME's documentation!
====================================

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-line: 0 
   :end-line: 1 

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-line: 2 
   :end-line: 8

.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-line: 15
   :end-line: 21

.. toctree::
   :maxdepth: 2
   :caption: Tutorials
   :hidden:

   notebooks/metatime_annotator

.. toctree::
   :maxdepth: 2
   :caption: API
   :hidden:
   
   metatime 
